@@ -28,7 +28,7 @@ print.clvkmeans =  function (x, ...)
   cat(paste("number of clusters: ", x$param$K), sep = " ")
   cat("\n")
   cat("\n")
-  cat("$tarbre: clustering criterion")
+  cat("$tabres: clustering criterion")
   cat("\n")
   cat("$clusters: groups membership")
   cat("\n")
